fpia: Fixed-Point Iteration Algorithm

View source: R/alg_other_authors.R

fpiaR Documentation

Fixed-Point Iteration Algorithm

Description

[Experimental]

Algorithm for optimum sample allocation in stratified sampling under lower- and upper-bound constraints, based on fixed-point iteration.

Usage

fpia(
  n,
  Ah,
  mh = NULL,
  Mh = NULL,
  lambda0 = NULL,
  maxiter = 100,
  tol = .Machine$double.eps * 1000
)

fpia2(v0, Nh, Sh, mh = NULL, Mh = NULL, lambda0 = NULL, maxiter = 100)

glambda(lambda, n, Ah, mh = NULL, Mh = NULL)

philambda(lambda, n, Ah, mh = NULL, Mh = NULL)

Arguments

n

(integerish(1))
total sample size.

Ah

(numeric)
products of population stratum sizes and standard deviations of the study variable, A_h = N_h S_h.

mh

(numeric or NULL)
lower bounds on stratum sample sizes (optional).

Mh

(numeric or NULL)
upper bounds on stratum sample sizes (optional).

lambda0

(numeric(1))
initial value of the parameter \lambda (optional).

maxiter

(integerish(1))
maximum number of iterations.

tol

(numeric(1))
desired convergence tolerance.

v0

variance

Nh

(numeric)
population sizes in strata.

Sh

(numeric)
standard deviations of the study variable in strata.

lambda

(numeric(1))
\lambda.

Value

A list with elements:

nh

Vector of optimal allocation sizes.

iter

Number of iterations performed.

Functions

  • fpia():

  • fpia2(): Variant of fpia() using variance-based parametrization.

  • glambda(): Helper function for the fpia()

  • philambda(): Helper function for the fpia().

References

\insertRef

MSWstratallo


stratallo documentation built on March 12, 2026, 5:06 p.m.