| data | R Documentation |
Example datasets containing artificial populations for testing and demonstrating optimum sample allocation algorithms.
pop10s_bounds_ucost
pop507s_ucost
pop969s_ucost
pop2d4s
pop9d278s
pop10s_bounds_ucost: Population with 10 strata, lower and upper bounds on sample sizes, and associated surveying costs. A matrix with 10 rows and 5 variables:
stratum size
standard deviation of study variable in the stratum.
lower bound for sample size in the stratum.
upper bound for sample size in the stratum.
cost of surveying one element in the stratum.
pop507s_ucost: Population with 507 strata and associated surveying costs. A matrix with 507 rows and 3 columns:
stratum size.
standard deviation of study variable in the stratum.
cost of surveying one element in the stratum.
pop969s_ucost: Population with 969 strata and associated surveying costs. A matrix with 969 rows and 3 columns:
stratum size.
standard deviation of study variable in the stratum.
cost of surveying one element in the stratum.
pop2d4s: Population with 2 domains and 4 strata. A list with the following elements:
strata counts in each domain.
stratum sizes.
standard deviations of study variable in strata.
totals in domains, i.e., the sum of the study variable values for population elements in each domain.
priority weights for domains.
total * sqrt(kappa).
total^2 * kappa.
See dca_nmax() or dca().
pop9d278s: Population with 9 domains and 278 strata. A list with the following elements:
strata counts in each domain.
stratum sizes.
standard deviations of study variable in strata.
totals in domains, i.e., the sum of the study variable values for population elements in each domain.
priority weights for domains.
total * sqrt(kappa).
total^2 * kappa.
See dca_nmax() or dca().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.