| is_equal | R Documentation |
Compares two numeric vectors element-wise using an adaptive tolerance
sequence ranging from 10^-19 to 10^tol_max. The smallest tolerance at
which the values are considered equal is returned as the corresponding name
in the output.
is_equal(x, y, tol_max = -1)
x |
( |
y |
( |
tol_max |
( |
A logical vector indicating whether each element pair is equal within the detected tolerance. The names reflect the tolerance used.
# internal functions (not exported) – examples skipped
## Not run:
is_equal(c(3, 4), c(3, 4))
is_equal(c(3, 4), c(3.01, 4.11))
is_equal(c(3, 4), c(3.01, 4.11), tol_max = 0)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.