| rna_experimental | R Documentation |
Experimental variants of the Recursive Neyman Algorithm (RNA).
rna_rec(
total_cost,
A,
bounds = NULL,
unit_costs = rep(1, length(A)),
cmp = .Primitive(">=")
)
rna_prior(
total_cost,
A,
bounds = NULL,
check = NULL,
cmp = .Primitive(">="),
details = FALSE
)
total_cost |
(
|
A |
( |
bounds |
(
See also |
unit_costs |
( |
cmp |
( The value of this argument has no effect if |
check |
( |
details |
( |
rna_rec(): Recursive implementation of the RNA.
rna_prior(): A variant of the Recursive Neyman Algorithm (RNA) that uses prior information
about strata for which allocation constraints may be violated. For all other
strata, allocations are assumed to satisfy the bounds.
This code has not been extensively tested and may change in future releases.
A <- c(3000, 4000, 5000, 2000)
M <- c(100, 90, 70, 80) # upper bounds
# experimental function (not exported) – examples skipped
## Not run:
rna_rec(total_cost = 190, A = A, bounds = M)
rna_rec(total_cost = 312, A = A, bounds = M)
rna_rec(total_cost = 339, A = A, bounds = M)
rna_rec(total_cost = 340, A = A, bounds = M)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.