simplegreedy-capacityscaling: SimpleGreedy and CapacityScaling Algorithms

simplegreedy-capacityscalingR Documentation

SimpleGreedy and CapacityScaling Algorithms

Description

[Experimental]

Fast integer-valued algorithms for optimum allocations under constraints in stratified sampling proposed in \insertCiteFriedrich;textualstratallo.

Usage

SimpleGreedy(
  n,
  Ah,
  mh = rep(1, length(Ah)),
  Mh = rep(Inf, length(Ah)),
  nh = mh
)

SimpleGreedy2(v0, Nh, Sh, mh = rep(1, length(Nh)), Mh = Nh, nh = mh)

CapacityScaling(n, Ah, mh = rep(1, length(Ah)), Mh = rep(Inf, length(Ah)))

CapacityScaling2(
  v0,
  Nh,
  Sh,
  mh = rep(1, length(Nh)),
  Mh = rep(Inf, length(Nh))
)

Arguments

n

(integerish(1))
total sample size.

Ah

(numeric)
products of population stratum sizes and standard deviations of the study variable, A_h = N_h S_h.

mh

(integerish)
lower bounds on stratum sample sizes.

Mh

(integerish)
upper bounds on stratum sample sizes.

nh

(integerish)
initial allocation. Defaults to mh.

v0

(numeric(1))
upper bound on the variance of the estimator.

Nh

(numeric)
population sizes in strata.

Sh

(numeric)
standard deviations of the study variable in strata.

Value

For the fpia() - an integer vector of optimum sample sizes allocated to each stratum.

Functions

  • SimpleGreedy():

  • SimpleGreedy2(): Variant of the SimpleGreedy algorithm based on a variance stopping rule.

  • CapacityScaling():

  • CapacityScaling2(): Variant of the CapacityScaling algorithm based on a variance stopping rule.

References

\insertRef

Friedrichstratallo


stratallo documentation built on March 12, 2026, 5:06 p.m.