| simplegreedy-capacityscaling | R Documentation |
Fast integer-valued algorithms for optimum allocations under constraints in stratified sampling proposed in \insertCiteFriedrich;textualstratallo.
SimpleGreedy(
n,
Ah,
mh = rep(1, length(Ah)),
Mh = rep(Inf, length(Ah)),
nh = mh
)
SimpleGreedy2(v0, Nh, Sh, mh = rep(1, length(Nh)), Mh = Nh, nh = mh)
CapacityScaling(n, Ah, mh = rep(1, length(Ah)), Mh = rep(Inf, length(Ah)))
CapacityScaling2(
v0,
Nh,
Sh,
mh = rep(1, length(Nh)),
Mh = rep(Inf, length(Nh))
)
n |
( |
Ah |
( |
mh |
( |
Mh |
( |
nh |
( |
v0 |
( |
Nh |
( |
Sh |
( |
For the fpia() - an integer vector of optimum sample sizes allocated to
each stratum.
SimpleGreedy():
SimpleGreedy2(): Variant of the SimpleGreedy algorithm based on a variance stopping
rule.
CapacityScaling():
CapacityScaling2(): Variant of the CapacityScaling algorithm based on a variance stopping
rule.
Friedrichstratallo
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.