Fast integer-valued algorithms for optimum allocations under constraints in stratified sampling proposed in Friedrich;textualstratallo.
SimpleGreedy(
n,
Ah,
mh = rep(1, length(Ah)),
Mh = rep(Inf, length(Ah)),
nh = mh
)SimpleGreedy2(v0, Nh, Sh, mh = rep(1, length(Nh)), Mh = Nh, nh = mh)
CapacityScaling(n, Ah, mh = rep(1, length(Ah)), Mh = rep(Inf, length(Ah)))
CapacityScaling2(
v0,
Nh,
Sh,
mh = rep(1, length(Nh)),
Mh = rep(Inf, length(Nh))
)
For the fpia() - an integer vector of optimum sample sizes allocated to
each stratum.
(integerish(1))
total sample size.
(numeric)
products of population stratum sizes and standard
deviations of the study variable, \(A_h = N_h S_h\).
(integerish)
lower bounds on stratum sample sizes.
(integerish)
upper bounds on stratum sample sizes.
(integerish)
initial allocation. Defaults to mh.
(numeric(1))
upper bound on the variance of the estimator.
(numeric)
population sizes in strata.
(numeric)
standard deviations of the study variable in strata.
SimpleGreedy():
SimpleGreedy2(): Variant of the SimpleGreedy algorithm based on a variance stopping
rule.
CapacityScaling():
CapacityScaling2(): Variant of the CapacityScaling algorithm based on a variance stopping
rule.
Friedrichstratallo